summaryrefslogtreecommitdiffstats
path: root/kate/part/kateview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kate/part/kateview.h')
-rw-r--r--kate/part/kateview.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kate/part/kateview.h b/kate/part/kateview.h
index aab0a6035..aa428096d 100644
--- a/kate/part/kateview.h
+++ b/kate/part/kateview.h
@@ -56,7 +56,7 @@ class TQGridLayout;
//
class KateView : public Kate::View,
public KTextEditor::SessionConfigInterface,
- public KTextEditor::ViewtqStatusMsgInterface,
+ public KTextEditor::ViewStatusMsgInterface,
public KTextEditor::TextHintInterface,
public KTextEditor::SelectionInterface,
public KTextEditor::SelectionInterfaceExt,
@@ -270,7 +270,7 @@ class KateView : public Kate::View,
void clear ();
- void tqrepaintText (bool paintOnlyDirty = false);
+ void repaintText (bool paintOnlyDirty = false);
void updateView (bool changed = false);
//END
@@ -376,14 +376,14 @@ class KateView : public Kate::View,
public slots:
int getEol();
void setEol( int eol );
- void tqfind();
- void tqfind( const TQString&, long, bool add=true ); ///< proxy for KateSearch
- void tqreplace();
- void tqreplace( const TQString&, const TQString &, long ); ///< proxy for KateSearch
- /** Highly confusing but KateSearch::tqfindAgain() is backwards too. */
- void tqfindAgain( bool back );
- void tqfindAgain() { tqfindAgain( false ); }
- void tqfindPrev() { tqfindAgain( true ); }
+ void find();
+ void find( const TQString&, long, bool add=true ); ///< proxy for KateSearch
+ void replace();
+ void replace( const TQString&, const TQString &, long ); ///< proxy for KateSearch
+ /** Highly confusing but KateSearch::findAgain() is backwards too. */
+ void findAgain( bool back );
+ void findAgain() { findAgain( false ); }
+ void findPrev() { findAgain( true ); }
void setFoldingMarkersOn( bool enable ); // Not in Kate::View, but should be
void setIconBorder( bool enable );
@@ -420,7 +420,7 @@ class KateView : public Kate::View,
signals:
void gotFocus( Kate::View* );
void lostFocus( Kate::View* );
- void newtqStatus(); // Not in Kate::View, but should be (Kate app connects to it)
+ void newStatus(); // Not in Kate::View, but should be (Kate app connects to it)
//
// Extras
@@ -443,7 +443,7 @@ class KateView : public Kate::View,
signals:
void dropEventPass(TQDropEvent*);
- void viewtqStatusMsg (const TQString &msg);
+ void viewStatusMsg (const TQString &msg);
public:
bool setCursorPositionInternal( uint line, uint col, uint tabwidth = 1, bool calledExternally = false );
@@ -459,7 +459,7 @@ class KateView : public Kate::View,
void slotGotFocus();
void slotLostFocus();
void slotDropEventPass( TQDropEvent* ev );
- void slottqStatusMsg();
+ void slotStatusMsg();
void slotSaveCanceled( const TQString& error );
void slotExpandToplevel();
void slotCollapseLocal();